==> vue-user-head-2.8.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/user-head/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import { IconUser } from "@dft-vue-2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconUser: IconUser()
  },
  emits: ["click", "mouseenter"],
  props: [].concat(props, ["min", "round", "color", "backgroundColor", "type", "modelValue", "messageTotal", "messageType", "messageUpperLimit", "size"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "inline-block relative",
    attrs: {
      "data-tag": "tiny-user-head"
    },
    on: {
      "click": _vm.handleClick,
      "mouseenter": _vm.mouseEnter
    }
  }, [_c("div", {
    class: ["overflow-hidden w-10 h-10  text-center rounded  bg-center bg-no-repeat bg-cover", {
      "h-8 w-8 leading-8": _vm.min
    }, {
      "[&_span]:overflow-hidden [&_span]:flex [&_span]:justify-center [&_span]:h-full px-0.5": _vm.type === "label"
    }, {
      "rounded-full": _vm.round
    }, {
      "[&_svg]:top-1/2  [&_svg]:absolute [&_svg]:left-1/2  [&_svg]:-translate-y-1/2 [&_svg]:-translate-x-1/2": _vm.type === "icon"
    }, {
      "text-sm": _vm.type === "icon" && _vm.min
    }],
    style: [_vm.state.style, {
      height: _vm.state.size + "px",
      width: _vm.state.size + "px",
      lineHeight: _vm.state.size + "px"
    }],
    attrs: {
      "data-tag": "tiny-user-head-body"
    }
  }, [_vm._t("default", [_vm.type === "icon" ? _c(_vm.state.internalValue, {
    tag: "component",
    staticClass: "inline-block w-6 h-6",
    style: [{
      height: _vm.state.size / 1.5 + "px",
      width: _vm.state.size / 1.5 + "px",
      lineHeight: _vm.state.size / 1.5 + "px",
      top: "" + _vm.state.size / 2
    }]
  }) : _vm._e(), _vm.type === "label" ? _c("span", {
    style: _vm.state.fontSize,
    attrs: {
      "title": _vm.state.internalValue
    }
  }, [_vm._v(_vm._s(_vm.state.label))]) : _vm._e()])], 2), _vm.messageTotal ? _c("div", {
    class: ["absolute rounded-lg text-color-text-primary text-center box-content bg-color-error", _vm.messageType === "basic" ? "w-0 h-1 px-0.5 border-2 -right-1.5 border-color-bg-1 border-solid -top-1 left-9" : "min-w-[0.625rem] w-auto left-7 flex items-center -top-2.5 px-0.5 text-xs h-3.5 border-2 border-color-bg-1 border-solid", {
      "-top-1 h-2 min-w-2 leading-none rounded": _vm.messageType === "icon"
    }, {
      "top-0 -right-1.5": (_vm.messageType === "basic" || _vm.messageType === "icon") && _vm.round
    }, {
      "-top-1.5 left-8 -right-1.5 w-3 h-3": (_vm.messageType === "basic" || _vm.messageType === "icon") && _vm.min
    }, {
      "top-0": (_vm.messageType === "basic" || _vm.messageType === "icon") && _vm.round && _vm.min
    }],
    attrs: {
      "data-tag": "tiny-user-head-message"
    }
  }, [_vm._v(" " + _vm._s(_vm.state.message) + " ")]) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-user-head-2.21.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/user-head/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconUser } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconUser: IconUser()
  },
  emits: ["click", "mouseenter"],
  props: [].concat(props, ["min", "round", "color", "backgroundColor", "type", "value", "modelValue", "messageTotal", "messageType", "messageUpperLimit", "size"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "inline-block relative",
    attrs: {
      "data-tag": "tiny-user-head"
    },
    on: {
      "click": _vm.handleClick,
      "mouseenter": _vm.mouseEnter
    }
  }, [_c("div", {
    class: ["overflow-hidden w-10 h-10  text-center  bg-center bg-no-repeat bg-cover", _vm.round ? "rounded-full" : "rounded", {
      "h-8 w-8 leading-8": _vm.min
    }, {
      "[&_span]:overflow-hidden [&_span]:flex [&_span]:justify-center [&_span]:h-full px-0.5": _vm.type === "label"
    }, {
      "[&_svg]:top-1/2  [&_svg]:absolute [&_svg]:left-1/2  [&_svg]:-translate-y-1/2 [&_svg]:-translate-x-1/2": _vm.type === "icon"
    }, {
      "text-sm": _vm.type === "icon" && _vm.min
    }],
    style: [_vm.state.style, {
      height: _vm.state.size + "px",
      width: _vm.state.size + "px",
      lineHeight: _vm.state.size + "px"
    }],
    attrs: {
      "data-tag": "tiny-user-head-body"
    }
  }, [_vm._t("default", function() {
    return [_vm.type === "icon" ? _c(_vm.state.internalValue, {
      tag: "component",
      staticClass: "inline-block w-6 h-6",
      style: [{
        height: _vm.state.size / 1.5 + "px",
        width: _vm.state.size / 1.5 + "px",
        lineHeight: _vm.state.size / 1.5 + "px",
        top: "" + _vm.state.size / 2
      }]
    }) : _vm._e(), _vm.type === "label" ? _c("span", {
      style: _vm.state.fontSize,
      attrs: {
        "title": _vm.state.internalValue
      }
    }, [_vm._v(_vm._s(_vm.state.label))]) : _vm._e()];
  })], 2), _vm.messageTotal ? _c("div", {
    class: ["absolute rounded-lg text-color-text-primary text-center box-content bg-color-error", _vm.messageType === "basic" ? "w-0 h-1 px-0.5 border-2 -right-1.5 border-color-bg-1 border-solid -top-1 left-9" : "min-w-[0.625rem] w-auto left-7 flex items-center -top-2.5 px-0.5 text-xs h-3.5 border-2 border-color-bg-1 border-solid", {
      "-top-1 h-2 min-w-2 leading-none rounded": _vm.messageType === "icon"
    }, {
      "top-0 -right-1.5": (_vm.messageType === "basic" || _vm.messageType === "icon") && _vm.round
    }, {
      "-top-1.5 left-8 -right-1.5 w-3 h-3": (_vm.messageType === "basic" || _vm.messageType === "icon") && _vm.min
    }, {
      "top-0": (_vm.messageType === "basic" || _vm.messageType === "icon") && _vm.round && _vm.min
    }],
    attrs: {
      "data-tag": "tiny-user-head-message"
    }
  }, [_vm._v(" " + _vm._s(_vm.state.message) + " ")]) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
